@@ -15,12 +15,13 @@ Puppet::Type.type(:nova_aggregate).provide(
   def self.instances
     request('aggregate', 'list').collect do |el|
       attrs = request('aggregate', 'show', el[:name])
+      properties = Hash[attrs[:properties].scan(/(\S+)='([^']*)'/)] rescue nil
       new(
           :ensure => :present,
           :name => attrs[:name],
           :id => attrs[:id],
           :availability_zone => attrs[:availability_zone],
-          :metadata => str2hash(attrs[:properties]),
+          :metadata => properties,
           :hosts => string2list(attrs[:hosts]).sort,
           :filter_hosts => attrs[:filter_hosts]
       )
@@ -86,14 +87,13 @@ Puppet::Type.type(:nova_aggregate).provide(
 
   def metadata=(value)
     # clear obsolete keys
-    # wip until #1559866
-#   if @property_hash[:metadata].keys.length > 0
-#     properties = [@resource[:name] ]
-#     (@property_hash[:metadata].keys - @resource[:metadata].keys).each do |key|
-#       properties << "--property" << "#{key}"
-#     end
-#     self.class.request('aggregate', 'unset', properties)
-#   end
+    if @property_hash[:metadata].keys.length > 0
+      properties = [@resource[:name] ]
+      (@property_hash[:metadata].keys - @resource[:metadata].keys).each do |key|
+        properties << "--property" << "#{key}"
+      end
+      self.class.request('aggregate', 'unset', properties)
+    end
     properties = [@resource[:name] ]
     @resource[:metadata].each do |key, value|
       properties << "--property" << "#{key}=#{value}"
