@@ -28,6 +28,7 @@ describe 'nova::compute' do
       it { is_expected.to contain_nova_config('DEFAULT/resize_confirm_window').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('DEFAULT/vcpu_pin_set').with(:value => '<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('DEFAULT/resume_guests_state_on_host_boot').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_nova_config('compute/cpu_shared_set').with(:value => '<SERVICE DEFAULT>') }
       it { is_expected.to_not contain_nova_config('vnc/novncproxy_base_url') }
       it { is_expected.to contain_nova_config('key_manager/backend').with_value('nova.keymgr.conf_key_mgr.ConfKeyManager') }
       it { is_expected.to contain_nova_config('barbican/barbican_endpoint').with_value('<SERVICE DEFAULT>') }
@@ -35,6 +36,8 @@ describe 'nova::compute' do
       it { is_expected.to contain_nova_config('barbican/auth_endpoint').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('glance/verify_glance_signatures').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('DEFAULT/max_concurrent_live_migrations').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_nova_config('DEFAULT/sync_power_state_pool_size').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_nova_config('DEFAULT/sync_power_state_interval').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('compute/consecutive_build_service_disable_threshold').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('DEFAULT/reserved_huge_pages').with_value('<SERVICE DEFAULT>') }
 
@@ -52,6 +55,23 @@ describe 'nova::compute' do
         is_expected.to contain_nova_config('DEFAULT/internal_service_availability_zone').with_value('<SERVICE DEFAULT>')
       end
 
+      it 'configures vendordata' do
+        is_expected.to contain_nova_config('api/vendordata_jsonfile_path').with('value' => '<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('api/vendordata_providers').with('value' => '<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('api/vendordata_dynamic_targets').with('value' => '<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('api/vendordata_dynamic_connect_timeout').with('value' => '<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('api/vendordata_dynamic_read_timeout').with('value' => '<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('api/vendordata_dynamic_failure_fatal').with('value' => '<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('vendordata_dynamic_auth/auth_type').with('value' => '<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('vendordata_dynamic_auth/auth_url').with('value' => '<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('vendordata_dynamic_auth/os_region_name').with('value' => '<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('vendordata_dynamic_auth/password').with('value' => '<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('vendordata_dynamic_auth/project_domain_name').with('value' => 'Default')
+        is_expected.to contain_nova_config('vendordata_dynamic_auth/project_name').with('value' => '<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('vendordata_dynamic_auth/user_domain_name').with('value' => 'Default')
+        is_expected.to contain_nova_config('vendordata_dynamic_auth/username').with('value' => '<SERVICE DEFAULT>')
+      end
+
       it { is_expected.to contain_nova_config('DEFAULT/heal_instance_info_cache_interval').with_value('60') }
 
       it 'installs genisoimage package and sets config_drive_format' do
@@ -75,12 +95,15 @@ describe 'nova::compute' do
           :config_drive_format                => 'vfat',
           :resize_confirm_window              => '3',
           :vcpu_pin_set                       => ['4-12','^8','15'],
+          :cpu_shared_set                     => ['4-12','^8','15'],
           :resume_guests_state_on_host_boot   => true,
           :keymgr_backend                     => 'castellan.key_manager.barbican_key_manager.BarbicanKeyManager',
           :barbican_endpoint                  => 'http://localhost',
           :barbican_api_version               => 'v1',
           :barbican_auth_endpoint             => 'http://127.0.0.1:5000/v3',
           :max_concurrent_live_migrations     => '4',
+          :sync_power_state_pool_size         => '10',
+          :sync_power_state_interval          => '0',
           :verify_glance_signatures           => true,
           :consecutive_build_service_disable_threshold => '9',
         }
@@ -116,12 +139,15 @@ describe 'nova::compute' do
       it 'configures vnc in nova.conf' do
         is_expected.to contain_nova_config('vnc/enabled').with_value(true)
         is_expected.to contain_nova_config('vnc/vncserver_proxyclient_address').with_value('127.0.0.1')
-        is_expected.to contain_nova_config('vnc/keymap').with_value('en-us')
         is_expected.to contain_nova_config('vnc/novncproxy_base_url').with_value(
           'http://127.0.0.1:6080/vnc_auto.html'
         )
       end
 
+      it 'should have spice disabled' do
+        is_expected.to contain_nova_config('spice/enabled').with_value(false)
+      end
+
       it { is_expected.to contain_nova_config('DEFAULT/heal_instance_info_cache_interval').with_value('120') }
 
       it { is_expected.to contain_nova_config('DEFAULT/force_raw_images').with(:value => false) }
@@ -130,8 +156,14 @@ describe 'nova::compute' do
 
       it { is_expected.to contain_nova_config('DEFAULT/vcpu_pin_set').with(:value => '4-12,^8,15') }
 
+      it { is_expected.to contain_nova_config('compute/cpu_shared_set').with(:value => '4-12,^8,15') }
+
       it { is_expected.to contain_nova_config('DEFAULT/max_concurrent_live_migrations').with_value('4') }
 
+      it { is_expected.to contain_nova_config('DEFAULT/sync_power_state_pool_size').with_value('10') }
+
+      it { is_expected.to contain_nova_config('DEFAULT/sync_power_state_interval').with_value('0') }
+
       it { is_expected.to contain_nova_config('compute/consecutive_build_service_disable_threshold').with_value('9') }
 
       it { is_expected.to contain_nova_config('DEFAULT/resume_guests_state_on_host_boot').with_value(true) }
@@ -171,18 +203,6 @@ describe 'nova::compute' do
       end
     end
 
-    context 'with barbican deprecated parameters' do
-      let :params do
-        {
-          :keymgr_api_class => 'castellan.key_manager.barbican_key_manager.BarbicanKeyManager',
-        }
-      end
-      it 'should set keymgr parameter' do
-        is_expected.to contain_nova_config('key_manager/backend').with_value('castellan.key_manager.barbican_key_manager.BarbicanKeyManager')
-        is_expected.to contain_package('cryptsetup').with( :ensure => 'present' )
-      end
-    end
-
     context 'when vcpu_pin_set and pci params are empty' do
       let :params do
         { :vcpu_pin_set    => ""}
@@ -193,6 +213,16 @@ describe 'nova::compute' do
       end
     end
 
+    context 'when cpu_shared_set is empty' do
+      let :params do
+        { :cpu_shared_set    => ""}
+      end
+
+      it 'clears cpu_shared_set configuration' do
+        is_expected.to contain_nova_config('compute/cpu_shared_set').with(:value => '<SERVICE DEFAULT>')
+      end
+    end
+
     context 'with neutron_enabled set to false' do
       let :params do
         { :neutron_enabled => false }
@@ -208,6 +238,28 @@ describe 'nova::compute' do
 
     end
 
+    context 'when neutron_physnets_numa_nodes_mapping and neutron_tunnel_numa_nodes are empty' do
+      let :params do
+        { :neutron_physnets_numa_nodes_mapping => {},
+          :neutron_tunnel_numa_nodes           => [], }
+      end
+
+      it { is_expected.to contain_nova_config('neutron/physnets').with(:ensure => 'absent') }
+      it { is_expected.to contain_nova_config('neutron_tunnel/numa_nodes').with(:ensure => 'absent') }
+    end
+
+    context 'when neutron_physnets_numa_nodes_mapping and neutron_tunnel_numa_nodes are set to valid values' do
+      let :params do
+        { :neutron_physnets_numa_nodes_mapping => { 'foo' => [0, 1], 'bar' => [0] },
+          :neutron_tunnel_numa_nodes           => 1, }
+      end
+
+      it { is_expected.to contain_nova_config('neutron/physnets').with(:value => 'foo,bar') }
+      it { is_expected.to contain_nova_config('neutron_physnet_foo/numa_nodes').with(:value => '0,1') }
+      it { is_expected.to contain_nova_config('neutron_physnet_bar/numa_nodes').with(:value => '0') }
+      it { is_expected.to contain_nova_config('neutron_tunnel/numa_nodes').with(:value => '1') }
+    end
+
     context 'with install_bridge_utils set to false' do
       let :params do
         { :install_bridge_utils => false }
@@ -221,17 +273,30 @@ describe 'nova::compute' do
 
     end
 
-    context 'with vnc_enabled set to false' do
+    context 'with vnc_enabled set to false and spice_enabled set to true' do
       let :params do
-        { :vnc_enabled => false }
+        { :vnc_enabled => false,
+          :spice_enabled => true, }
       end
 
       it 'disables vnc in nova.conf' do
         is_expected.to contain_nova_config('vnc/enabled').with_value(false)
         is_expected.to contain_nova_config('vnc/vncserver_proxyclient_address').with_ensure('absent')
-        is_expected.to contain_nova_config('vnc/keymap').with_ensure('absent')
         is_expected.to_not contain_nova_config('vnc/novncproxy_base_url')
       end
+
+      it 'enables spice' do
+        is_expected.to contain_nova_config('spice/enabled').with_value(true)
+      end
+    end
+
+    context 'with vnc_enabled and spice_enabled set to true' do
+      let :params do
+        { :vnc_enabled   => true,
+          :spice_enabled => true, }
+      end
+
+      it { is_expected.to raise_error Puppet::Error, /vnc_enabled and spice_enabled is mutually exclusive/ }
     end
 
     context 'with force_config_drive parameter set to true' do
@@ -281,13 +346,6 @@ describe 'nova::compute' do
       it { is_expected.to contain_nova_config('DEFAULT/instance_usage_audit_period').with_value('year') }
     end
 
-    context 'with vnc_keymap set to fr' do
-      let :params do
-        { :vnc_keymap => 'fr', }
-      end
-
-      it { is_expected.to contain_nova_config('vnc/keymap').with_value('fr') }
-    end
   end
 
   on_supported_os({
