@@ -8,7 +8,6 @@ describe 'nova::scheduler' do
 
   shared_examples 'nova-scheduler' do
 
-
     it { is_expected.to contain_package('nova-scheduler').with(
       :name   => platform_params[:scheduler_package_name],
       :ensure => 'present'
@@ -20,6 +19,7 @@ describe 'nova::scheduler' do
       :ensure    => 'running'
     )}
 
+    it { is_expected.to contain_nova_config('scheduler/workers').with_value(4) }
     it { is_expected.to contain_nova_config('scheduler/driver').with_value('filter_scheduler') }
     it { is_expected.to contain_nova_config('scheduler/discover_hosts_in_cells_interval').with_value('<SERVICE DEFAULT>') }
 
@@ -42,6 +42,14 @@ describe 'nova::scheduler' do
       )}
     end
 
+    context 'with workers' do
+      let :params do
+        { :workers => 8 }
+      end
+
+      it { is_expected.to contain_nova_config('scheduler/workers').with_value(8) }
+    end
+
     context 'with scheduler driver' do
       let :params do
         { :scheduler_driver => 'custom driver' }
@@ -87,30 +95,27 @@ describe 'nova::scheduler' do
 
   end
 
-  context 'on Debian platforms' do
-    let :facts do
-      @default_facts.merge({ :osfamily => 'Debian' })
+  on_supported_os({
+    :supported_os => OSDefaults.get_supported_os
+  }).each do |os,facts|
+    context "on #{os}" do
+      let (:facts) do
+        facts.merge!(OSDefaults.get_facts({ :os_workers => 4 }))
+      end
+
+      let (:platform_params) do
+        case facts[:osfamily]
+        when 'Debian'
+          { :scheduler_package_name => 'nova-scheduler',
+            :scheduler_service_name => 'nova-scheduler' }
+        when 'RedHat'
+          { :scheduler_package_name => 'openstack-nova-scheduler',
+            :scheduler_service_name => 'openstack-nova-scheduler' }
+        end
+      end
+
+      it_configures 'nova-scheduler'
     end
-
-    let :platform_params do
-      { :scheduler_package_name => 'nova-scheduler',
-        :scheduler_service_name => 'nova-scheduler' }
-    end
-
-    it_configures 'nova-scheduler'
-  end
-
-  context 'on Redhat platforms' do
-    let :facts do
-      @default_facts.merge({ :osfamily => 'RedHat' })
-    end
-
-    let :platform_params do
-      { :scheduler_package_name => 'openstack-nova-scheduler',
-        :scheduler_service_name => 'openstack-nova-scheduler' }
-    end
-
-    it_configures 'nova-scheduler'
   end
 
 end
